@@ -1,4 +1,4 @@
-# $Id: simtest.R,v 1.45 2003/02/12 10:24:41 hothorn Exp $
+# $Id: simtest.R,v 1.46 2003/02/18 08:27:56 hothorn Exp $
 
 simtest <- function(y, ...) UseMethod("simtest")
 
@@ -17,7 +17,7 @@ simtest.default <- function(y, x=NULL, type=c("Dunnett", "Tukey",
     rankx  <- sum(diag((xpxi %*% (t(x) %*% x))))
     n      <- nrow(x)
     p      <- ncol(x)
-    df     <- n-rankx
+    df     <- ceiling(n-rankx)
     estpar <- xpxi %*% t(x) %*% y
     mse    <- t(y-x %*% estpar) %*% (y-x %*% estpar)/df
     covm   <- mse[1,1]*xpxi
@@ -40,7 +40,7 @@ simtest.default <- function(y, x=NULL, type=c("Dunnett", "Tukey",
     if (nzerocol[2] != 0)
       cm <- cbind(cm, matrix(0, ncol=nzerocol[2], nrow=nrow(cm)))
 
-    csimtest(estpar, as.integer(df), covm, cm, ctype, ttype,
+    csimtest(estpar, df, covm, cm, ctype, ttype,
          alternative,  asympt, eps, maxpts)
 }
 
